"use strict";var a=function(r,e){return function(){return e||r((e={exports:{}}).exports,e),e.exports}};var s=a(function(b,i){
function u(r){return r!==null&&typeof r=="object"}i.exports=u
});var c=require('@stdlib/utils-define-nonenumerable-read-only-property/dist'),n=require('@stdlib/assert-tools-array-function/dist'),t=s(),o=n(t);c(t,"isObjectLikeArray",o);module.exports=t;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
